@@ -3,7 +3,7 @@ use lib 'lib';
 use Applify;
 
 option file => input_file => 'File to read from', 'Makefile.PL';
-option dir => output_dir => 'Directory to write files to', '.';
+option str => output_dir => 'Directory to write files to', n_of => '0,2';
 option flag => dry_run => 'Use --no-dry-run to actually do something', required => 1;
 
 version 1.23;
@@ -19,7 +19,8 @@ app {
 
     print "Extra arguments: @extra\n" if(@extra);
     print "Will read from: ", $self->input_file, "\n";
-    print "Will write files to: ", $self->output_dir, "\n";
+    print "Will write files to ", int @{ $self->output_dir }, " output dirs\n";
+    print "Will write files to: ", join(', ', @{ $self->output_dir }), "\n";
 
     if($self->dry_run) {
         die 'Will not run script';
@@ -32,6 +33,12 @@ app {
 
 test1.pl - Example script
 
+=head1 SYNOPSIS
+
+Some description...
+
+    test1.pl --help
+
 =head1 DESCRIPTION
 
 This script is just an example script...
